(new Object(){
    public String getJsonValue(String json, String path) {
        try {
            // Remove whitespace at start/end
            json = json.trim();
            
            // Split the path by dots to handle nested properties
            String[] pathParts = path.split("\\.");
            
            if (pathParts.length == 1) {
                // For simple top-level keys, use existing approach
                String topLevelPattern = "\"" + path + "\":";
                
                // First try to find as a top-level property
                int startPos = json.indexOf("{");
                if (startPos >= 0) {
                    int keyPos = json.indexOf(topLevelPattern, startPos);
                    if (keyPos > 0) {
                        int valueStart = keyPos + topLevelPattern.length();
                        
                        // Skip whitespace
                        while (valueStart < json.length() && 
                               Character.isWhitespace(json.charAt(valueStart))) {
                            valueStart++;
                        }
                        
                        if (valueStart < json.length()) {
                            char c = json.charAt(valueStart);
                            
                            // Handle string value
                            if (c == '"') {
                                int valueEnd = findClosingQuote(json, valueStart + 1);
                                if (valueEnd > valueStart) {
                                    return json.substring(valueStart + 1, valueEnd);
                                }
                            }
                            // Handle number, boolean, or null
                            else if (Character.isDigit(c) || c == '-' || c == 't' || c == 'f' || c == 'n') {
                                int valueEnd = findEndOfPrimitive(json, valueStart);
                                return json.substring(valueStart, valueEnd);
                            }
                            // Handle object
                            else if (c == '{') {
                                int valueEnd = findClosingBrace(json, valueStart);
                                if (valueEnd > valueStart) {
                                    return json.substring(valueStart, valueEnd + 1);
                                }
                            }
                            // Handle array
                            else if (c == '[') {
                                int valueEnd = findClosingBracket(json, valueStart);
                                if (valueEnd > valueStart) {
                                    return json.substring(valueStart, valueEnd + 1);
                                }
                            }
                        }
                    }
                }
                
                // If all else fails, just use a simple search for the exact key
                String pattern = "\"" + path + "\":";
                int keyPos = json.indexOf(pattern);
                if (keyPos >= 0) {
                    int valueStart = keyPos + pattern.length();
                    
                    // Skip whitespace
                    while (valueStart < json.length() && 
                          Character.isWhitespace(json.charAt(valueStart))) {
                        valueStart++;
                    }
                    
                    if (valueStart < json.length()) {
                        char c = json.charAt(valueStart);
                        
                        // Handle string value
                        if (c == '"') {
                            int valueEnd = findClosingQuote(json, valueStart + 1);
                            if (valueEnd > valueStart) {
                                return json.substring(valueStart + 1, valueEnd);
                            }
                        }
                        // Handle number, boolean, or null
                        else if (Character.isDigit(c) || c == '-' || c == 't' || c == 'f' || c == 'n') {
                            int valueEnd = findEndOfPrimitive(json, valueStart);
                            return json.substring(valueStart, valueEnd);
                        }
                        // Handle object
                        else if (c == '{') {
                            int valueEnd = findClosingBrace(json, valueStart);
                            if (valueEnd > valueStart) {
                                return json.substring(valueStart, valueEnd + 1);
                            }
                        }
                        // Handle array
                        else if (c == '[') {
                            int valueEnd = findClosingBracket(json, valueStart);
                            if (valueEnd > valueStart) {
                                return json.substring(valueStart, valueEnd + 1);
                            }
                        }
                    }
                }
            } else {
                // Handle nested paths
                String currentJson = json;
                
                // Navigate through each part of the path
                for (int i = 0; i < pathParts.length; i++) {
                    String currentKey = pathParts[i];
                    
                    // Handle array index if the key is a number inside brackets like items[0]
                    if (currentKey.contains("[") && currentKey.endsWith("]")) {
                        int bracketPos = currentKey.indexOf("[");
                        String arrayKey = currentKey.substring(0, bracketPos);
                        String indexStr = currentKey.substring(bracketPos + 1, currentKey.length() - 1);
                        
                        try {
                            int index = Integer.parseInt(indexStr);
                            
                            // First get the array
                            String arrayJson = getJsonValue(currentJson, arrayKey);
                            if (arrayJson.startsWith("[") && arrayJson.endsWith("]")) {
                                // Parse the array to get the element at the specified index
                                String element = getArrayElement(arrayJson, index);
                                if (element.isEmpty()) {
                                    return ""; // Index out of bounds or invalid array
                                }
                                
                                // If this is the last part of the path, return the element
                                if (i == pathParts.length - 1) {
                                    return element;
                                }
                                
                                // Otherwise, continue with this element as the new context
                                currentJson = element;
                                continue;
                            } else {
                                return ""; // Not an array
                            }
                        } catch (NumberFormatException e) {
                            return ""; // Invalid index
                        }
                    }
                    
                    // Regular object property
                    String pattern = "\"" + currentKey + "\":";
                    int keyPos = currentJson.indexOf(pattern);
                    
                    if (keyPos < 0) {
                        return ""; // Key not found
                    }
                    
                    int valueStart = keyPos + pattern.length();
                    
                    // Skip whitespace
                    while (valueStart < currentJson.length() && 
                           Character.isWhitespace(currentJson.charAt(valueStart))) {
                        valueStart++;
                    }
                    
                    if (valueStart >= currentJson.length()) {
                        return ""; // Unexpected end of JSON
                    }
                    
                    char c = currentJson.charAt(valueStart);
                    
                    // If this is the last part of the path, extract the value
                    if (i == pathParts.length - 1) {
                        // Handle string value
                        if (c == '"') {
                            int valueEnd = findClosingQuote(currentJson, valueStart + 1);
                            if (valueEnd > valueStart) {
                                return currentJson.substring(valueStart + 1, valueEnd);
                            }
                        }
                        // Handle number, boolean, or null
                        else if (Character.isDigit(c) || c == '-' || c == 't' || c == 'f' || c == 'n') {
                            int valueEnd = findEndOfPrimitive(currentJson, valueStart);
                            return currentJson.substring(valueStart, valueEnd);
                        }
                        // Handle object
                        else if (c == '{') {
                            int valueEnd = findClosingBrace(currentJson, valueStart);
                            if (valueEnd > valueStart) {
                                return currentJson.substring(valueStart, valueEnd + 1);
                            }
                        }
                        // Handle array
                        else if (c == '[') {
                            int valueEnd = findClosingBracket(currentJson, valueStart);
                            if (valueEnd > valueStart) {
                                return currentJson.substring(valueStart, valueEnd + 1);
                            }
                        }
                    } else {
                        // If not the last part, we need to extract the object and continue
                        if (c == '{') {
                            int valueEnd = findClosingBrace(currentJson, valueStart);
                            if (valueEnd > valueStart) {
                                currentJson = currentJson.substring(valueStart, valueEnd + 1);
                                continue;
                            }
                        }
                        // Handle array as context for the next path part
                        else if (c == '[') {
                            int valueEnd = findClosingBracket(currentJson, valueStart);
                            if (valueEnd > valueStart) {
                                currentJson = currentJson.substring(valueStart, valueEnd + 1);
                                continue;
                            }
                        }
                        else {
                            return ""; // Expected object or array for nested path
                        }
                    }
                }
            }
            
            return ""; // Not found or error
        } catch (Exception e) {
            e.printStackTrace();
            return "error: " + e.getMessage();
        }
    }
    
    private String getArrayElement(String arrayJson, int index) {
        try {
            // Remove the brackets
            String content = arrayJson.substring(1, arrayJson.length() - 1).trim();
            if (content.isEmpty()) {
                return ""; // Empty array
            }
            
            int currentIndex = 0;
            int startPos = 0;
            boolean inString = false;
            int braceCount = 0;
            int bracketCount = 0;
            
            for (int i = 0; i < content.length(); i++) {
                char c = content.charAt(i);
                
                if (c == '"' && (i == 0 || content.charAt(i - 1) != '\\')) {
                    inString = !inString;
                } else if (!inString) {
                    if (c == '{') {
                        braceCount++;
                    } else if (c == '}') {
                        braceCount--;
                    } else if (c == '[') {
                        bracketCount++;
                    } else if (c == ']') {
                        bracketCount--;
                    } else if (c == ',' && braceCount == 0 && bracketCount == 0) {
                        // This is a top-level comma separating array elements
                        if (currentIndex == index) {
                            return content.substring(startPos, i).trim();
                        }
                        currentIndex++;
                        startPos = i + 1;
                    }
                }
            }
            
            // Check if the last element is the one we want
            if (currentIndex == index) {
                return content.substring(startPos).trim();
            }
            
            return ""; // Index out of bounds
        } catch (Exception e) {
            return "";
        }
    }
    
    private int findClosingQuote(String json, int start) {
        boolean escaped = false;
        for (int i = start; i < json.length(); i++) {
            char c = json.charAt(i);
            if (c == '\\') {
                escaped = !escaped;
            } else if (c == '"' && !escaped) {
                return i;
            } else {
                escaped = false;
            }
        }
        return -1;
    }
    
    private int findEndOfPrimitive(String json, int start) {
        for (int i = start; i < json.length(); i++) {
            char c = json.charAt(i);
            if (c == ',' || c == '}' || c == ']' || Character.isWhitespace(c)) {
                return i;
            }
        }
        return json.length();
    }
    
    private int findClosingBrace(String json, int start) {
        int braceCount = 1;
        boolean inString = false;
        
        for (int i = start + 1; i < json.length(); i++) {
            char c = json.charAt(i);
            
            if (c == '"' && (i == 0 || json.charAt(i - 1) != '\\')) {
                inString = !inString;
            } else if (!inString) {
                if (c == '{') {
                    braceCount++;
                } else if (c == '}') {
                    braceCount--;
                    if (braceCount == 0) {
                        return i;
                    }
                }
            }
        }
        
        return -1;
    }
    
    private int findClosingBracket(String json, int start) {
        int bracketCount = 1;
        boolean inString = false;
        
        for (int i = start + 1; i < json.length(); i++) {
            char c = json.charAt(i);
            
            if (c == '"' && (i == 0 || json.charAt(i - 1) != '\\')) {
                inString = !inString;
            } else if (!inString) {
                if (c == '[') {
                    bracketCount++;
                } else if (c == ']') {
                    bracketCount--;
                    if (bracketCount == 0) {
                        return i;
                    }
                }
            }
        }
        
        return -1;
    }
}.getJsonValue(${input$json}, ${input$key}))